@@ -14,9 +14,11 @@
 0.0.11: 发布测试版本 v0.0.11
 0.0.12: 发布测试版本 v0.0.12
 0.0.13: 发布测试版本 v0.0.13
+0.0.14: 发布测试版本 v0.0.14
+0.0.15: 发布测试版本 v0.0.15
 """
 
-__version__ = '0.0.13'
+__version__ = '0.0.15'
 __author__ = 'mssdk'
 
 import sys
@@ -27,6 +29,8 @@ if sys.version_info < (3, 7):
 
 del sys
 
+from mssdk.score.score import Score
+
 """
 东方财富-行业板块
 """
